@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import copy
 import re
+import warnings
 
 from contextlib import contextmanager
 from pathlib import Path
@@ -10,22 +11,23 @@ from typing import Collection
 from typing import Iterable
 from typing import Iterator
 from typing import TypeVar
-from typing import cast
 
+from poetry.core.constraints.version import parse_constraint
+from poetry.core.constraints.version.exceptions import ParseConstraintError
 from poetry.core.packages.dependency_group import MAIN_GROUP
 from poetry.core.packages.specification import PackageSpecification
 from poetry.core.packages.utils.utils import create_nested_marker
-from poetry.core.semver.helpers import parse_constraint
+from poetry.core.version.exceptions import InvalidVersion
 from poetry.core.version.markers import parse_marker
 
 
 if TYPE_CHECKING:
     from packaging.utils import NormalizedName
 
+    from poetry.core.constraints.version import Version
+    from poetry.core.constraints.version import VersionConstraint
     from poetry.core.packages.dependency import Dependency
     from poetry.core.packages.dependency_group import DependencyGroup
-    from poetry.core.semver.version import Version
-    from poetry.core.semver.version_constraint import VersionConstraint
     from poetry.core.spdx.license import License
     from poetry.core.version.markers import BaseMarker
 
@@ -46,6 +48,7 @@ class Package(PackageSpecification):
         "3.8",
         "3.9",
         "3.10",
+        "3.11",
     }
 
     def __init__(
@@ -67,6 +70,16 @@ class Package(PackageSpecification):
         """
         from poetry.core.version.markers import AnyMarker
 
+        if pretty_version is not None:
+            warnings.warn(
+                (
+                    "The `pretty_version` parameter is deprecated and will be removed"
+                    " in a future release."
+                ),
+                DeprecationWarning,
+                stacklevel=2,
+            )
+
         super().__init__(
             name,
             source_type=source_type,
@@ -77,7 +90,7 @@ class Package(PackageSpecification):
             features=features,
         )
 
-        self._set_version(version, pretty_version)
+        self._set_version(version)
 
         self.description = ""
 
@@ -91,7 +104,7 @@ class Package(PackageSpecification):
         self._license: License | None = None
         self.readmes: tuple[Path, ...] = ()
 
-        self.extras: dict[str, list[Dependency]] = {}
+        self.extras: dict[NormalizedName, list[Dependency]] = {}
 
         self._dependency_groups: dict[str, DependencyGroup] = {}
 
@@ -106,7 +119,6 @@ class Package(PackageSpecification):
         self._python_constraint = parse_constraint("*")
         self._python_marker: BaseMarker = AnyMarker()
 
-        self.platform = None
         self.marker: BaseMarker = AnyMarker()
 
         self.root_dir: Path | None = None
@@ -129,7 +141,7 @@ class Package(PackageSpecification):
 
     @property
     def pretty_version(self) -> str:
-        return self._pretty_version
+        return self._version.text
 
     @property
     def unique_name(self) -> str:
@@ -145,22 +157,22 @@ class Package(PackageSpecification):
     @property
     def full_pretty_version(self) -> str:
         if self.source_type in ["file", "directory", "url"]:
-            return f"{self._pretty_version} {self.source_url}"
+            return f"{self.pretty_version} {self.source_url}"
 
         if self.source_type not in ["hg", "git"]:
-            return self._pretty_version
+            return self.pretty_version
 
         ref: str | None
         if self.source_resolved_reference and len(self.source_resolved_reference) == 40:
             ref = self.source_resolved_reference[0:7]
-            return f"{self._pretty_version} {ref}"
+            return f"{self.pretty_version} {ref}"
 
         # if source reference is a sha1 hash -- truncate
         if self.source_reference and len(self.source_reference) == 40:
-            return f"{self._pretty_version} {self.source_reference[0:7]}"
+            return f"{self.pretty_version} {self.source_reference[0:7]}"
 
         ref = self._source_resolved_reference or self._source_reference
-        return f"{self._pretty_version} {ref}"
+        return f"{self.pretty_version} {ref}"
 
     @property
     def authors(self) -> list[str]:
@@ -209,17 +221,18 @@ class Package(PackageSpecification):
             for dependency in group.dependencies
         ]
 
-    def _set_version(
-        self, version: str | Version, pretty_version: str | None = None
-    ) -> None:
-        from poetry.core.semver.version import Version
+    def _set_version(self, version: str | Version) -> None:
+        from poetry.core.constraints.version import Version
 
         if not isinstance(version, Version):
-            self._version = Version.parse(version)
-            self._pretty_version = pretty_version or version
-        else:
-            self._version = version
-            self._pretty_version = pretty_version or self._version.text
+            try:
+                version = Version.parse(version)
+            except InvalidVersion:
+                raise InvalidVersion(
+                    f"Invalid version '{version}' on package {self.name}"
+                )
+
+        self._version = version
 
     def _get_author(self) -> dict[str, str | None]:
         if not self._authors:
@@ -261,8 +274,13 @@ class Package(PackageSpecification):
 
     @python_versions.setter
     def python_versions(self, value: str) -> None:
+        try:
+            constraint = parse_constraint(value)
+        except ParseConstraintError:
+            raise ParseConstraintError(f"Invalid python versions '{value}' on {self}")
+
         self._python_versions = value
-        self._python_constraint = parse_constraint(value)
+        self._python_constraint = constraint
         self._python_marker = parse_marker(
             create_nested_marker("python_version", self._python_constraint)
         )
@@ -291,7 +309,7 @@ class Package(PackageSpecification):
 
     @property
     def all_classifiers(self) -> list[str]:
-        from poetry.core.semver.version import Version
+        from poetry.core.constraints.version import Version
 
         classifiers = copy.copy(self.classifiers)
 
@@ -358,23 +376,25 @@ class Package(PackageSpecification):
 
     @property
     def readme(self) -> Path | None:
-        import warnings
-
         warnings.warn(
-            "`readme` is deprecated: you are getting only the first readme file. Please"
-            " use the plural form `readmes`.",
+            (
+                "`readme` is deprecated: you are getting only the first readme file."
+                " Please use the plural form `readmes`."
+            ),
             DeprecationWarning,
+            stacklevel=2,
         )
         return next(iter(self.readmes), None)
 
     @readme.setter
     def readme(self, path: Path) -> None:
-        import warnings
-
         warnings.warn(
-            "`readme` is deprecated. Please assign a tuple to the plural form"
-            " `readmes`.",
+            (
+                "`readme` is deprecated. Please assign a tuple to the plural form"
+                " `readmes`."
+            ),
             DeprecationWarning,
+            stacklevel=2,
         )
         self.readmes = (path,)
 
@@ -482,9 +502,10 @@ class Package(PackageSpecification):
 
         dep: Dependency
         if self.source_type == "directory":
+            assert self._source_url is not None
             dep = DirectoryDependency(
                 self._name,
-                Path(cast(str, self._source_url)),
+                Path(self._source_url),
                 groups=list(self._dependency_groups.keys()),
                 optional=self.optional,
                 base=self.root_dir,
@@ -492,28 +513,31 @@ class Package(PackageSpecification):
                 extras=self.features,
             )
         elif self.source_type == "file":
+            assert self._source_url is not None
             dep = FileDependency(
                 self._name,
-                Path(cast(str, self._source_url)),
+                Path(self._source_url),
                 groups=list(self._dependency_groups.keys()),
                 optional=self.optional,
                 base=self.root_dir,
                 extras=self.features,
             )
         elif self.source_type == "url":
+            assert self._source_url is not None
             dep = URLDependency(
                 self._name,
-                cast(str, self._source_url),
+                self._source_url,
                 directory=self.source_subdirectory,
                 groups=list(self._dependency_groups.keys()),
                 optional=self.optional,
                 extras=self.features,
             )
         elif self.source_type == "git":
+            assert self._source_url is not None
             dep = VCSDependency(
                 self._name,
                 self.source_type,
-                cast(str, self.source_url),
+                self._source_url,
                 rev=self.source_reference,
                 resolved_rev=self.source_resolved_reference,
                 directory=self.source_subdirectory,
@@ -552,16 +576,47 @@ class Package(PackageSpecification):
         """
         Helper method to check if this package satisfies a given dependency.
 
-        This is determined by assessing if this instance provides the package and
-        features specified by the given dependency. Further, version and source
-        types are checked.
+        This is determined by assessing if this instance provides the package specified
+        by the given dependency. Further, version and source types are checked.
         """
-        if not self.provides(dependency) or not dependency.constraint.allows(
-            self.version
-        ):
+        if self.name != dependency.name:
             return False
 
-        return ignore_source_type or self.is_same_source_as(dependency)
+        if not dependency.constraint.allows(self.version):
+            return False
+
+        if not ignore_source_type and not self.source_satisfies(dependency):
+            return False
+
+        return True
+
+    def source_satisfies(self, dependency: Dependency) -> bool:
+        """Determine whether this package's source satisfies the given dependency."""
+        if dependency.source_type is None:
+            if dependency.source_name is None:
+                # The dependency doesn't care about the source, so this package
+                # certainly satisfies it.
+                return True
+
+            # The dependency specifies a source_name but not a type: it wants either
+            # pypi or a legacy repository.
+            #
+            # - If this package has no source type then it's from pypi, so it
+            #   matches if and only if that's what the dependency wants
+            # - Else this package is a match if and only if it is from the desired
+            #   repository
+            if self.source_type is None:
+                return dependency.source_name.lower() == "pypi"
+
+            return (
+                self.source_type == "legacy"
+                and self.source_reference is not None
+                and self.source_reference.lower() == dependency.source_name.lower()
+            )
+
+        # The dependency specifies a source: this package matches if and only if it is
+        # from that source.
+        return dependency.is_same_source_as(self)
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, Package):
